@@ -1,5 +1,7 @@
+# kate: default-dictionary en_US
+
 ## This file is part of the 'stringi' package for R.
-## Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
+## Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
 ## All rights reserved.
 ##
 ## Redistribution and use in source and binary forms, with or without
@@ -17,7 +19,7 @@
 ## this software without specific prior written permission.
 ##
 ## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
+## 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING,
 ## BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 ## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 ## HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
@@ -37,9 +39,9 @@
 #'
 #' @details
 #' For non-printable and certain special (well-known,
-#' see also \R man page \link{Quotes})
+#' see also R man page \link{Quotes})
 #' ASCII characters the following
-#' (also recognized in \R) convention is used.
+#' (also recognized in R) convention is used.
 #' We get \code{\\a}, \code{\\b}, \code{\\t}, \code{\\n}, \code{\\v},
 #' \code{\\f}, \code{\\r}, \code{\"}, \code{\'}, \code{\\\\}
 #' or either {\\uXXXX} (4 hex digits) or {\\UXXXXXXXX} (8 hex digits)
@@ -51,27 +53,29 @@
 #'
 #'
 #' @param str character vector
+#'
 #' @return
 #' Returns a character vector.
 #'
 #' @examples
-#' stri_escape_unicode("a\u0105!")
+#' stri_escape_unicode('a\u0105!')
 #'
 #' @family escape
 #' @export
-stri_escape_unicode <- function(str) {
-   .Call(C_stri_escape_unicode, str)
+stri_escape_unicode <- function(str)
+{
+    .Call(C_stri_escape_unicode, str)
 }
 
 
 #' @title
-#' Unescape All Escape Sequences
+#' Un-escape All Escape Sequences
 #'
 #' @description
-#' Unescapes all known escape sequences
+#' Un-escapes all known escape sequences
 #'
 #' @details
-#' Uses \pkg{ICU} facilities to unescape Unicode character sequences.
+#' Uses \pkg{ICU} facilities to un-escape Unicode character sequences.
 #'
 #' The following ASCII standard escapes are recognized:
 #' \code{\\a}, \code{\\b}, \code{\\t}, \code{\\n}, \code{\\v}, \code{\\?},
@@ -84,23 +88,25 @@ stri_escape_unicode <- function(str) {
 #' \code{\\xXX} (1-2 hex digits),
 #' \code{\\ooo} (1-3 octal digits),
 #' \code{\\cX} (control-X; X is masked with 0x1F).
-#' For \code{\\xXX} and \code{\\ooo} beware of non-valid UTF8 byte sequences.
+#' For \code{\\xXX} and \code{\\ooo}, beware of non-valid UTF-8 byte sequences.
 #'
-#' Note that some versions of \R on Windows cannot handle
+#' Note that some versions of R on Windows cannot handle
 #' characters defined with  {\\UXXXXXXXX}.
 #' We are working on that.
 #'
 #' @param str character vector
+#'
 #' @return
 #' Returns a character vector.
 #' If an escape sequence is ill-formed,
 #' result will be \code{NA} and a warning will be given.
 #'
 #' @examples
-#' stri_unescape_unicode("a\\u0105!\\u0032\\n")
+#' stri_unescape_unicode('a\\u0105!\\u0032\\n')
 #'
 #' @family escape
 #' @export
-stri_unescape_unicode <- function(str) {
-   .Call(C_stri_unescape_unicode, str)
+stri_unescape_unicode <- function(str)
+{
+    .Call(C_stri_unescape_unicode, str)
 }
