@@ -1,5 +1,5 @@
-/* This file is part of the 'stringi' package for R.
- * Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+/* This file is part of the 'stringi' project.
+ * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -68,54 +68,58 @@
  *    #232: `max_count` arg added
  */
 SEXP stri_detect_coll(SEXP str, SEXP pattern, SEXP negate,
-    SEXP max_count, SEXP opts_collator)
+                      SEXP max_count, SEXP opts_collator)
 {
-   bool negate_1 = stri__prepare_arg_logical_1_notNA(negate, "negate");
-   int max_count_1 = stri__prepare_arg_integer_1_notNA(max_count, "max_count");
-   PROTECT(str = stri_prepare_arg_string(str, "str"));
-   PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
+    bool negate_1 = stri__prepare_arg_logical_1_notNA(negate, "negate");
+    int max_count_1 = stri__prepare_arg_integer_1_notNA(max_count, "max_count");
+    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(pattern = stri_prepare_arg_string(pattern, "pattern"));
 
-   // call stri__ucol_open after prepare_arg:
-   // if prepare_arg had failed, we would have a mem leak
-   UCollator* collator = NULL;
-   collator = stri__ucol_open(opts_collator);
+    // call stri__ucol_open after prepare_arg:
+    // if prepare_arg had failed, we would have a mem leak
+    UCollator* collator = NULL;
+    collator = stri__ucol_open(opts_collator);
 
-   STRI__ERROR_HANDLER_BEGIN(2)
-   R_len_t vectorize_length = stri__recycling_rule(true, 2, LENGTH(str), LENGTH(pattern));
-   StriContainerUTF16 str_cont(str, vectorize_length);
-   StriContainerUStringSearch pattern_cont(pattern, vectorize_length, collator);  // collator is not owned by pattern_cont
+    STRI__ERROR_HANDLER_BEGIN(2)
+    R_len_t vectorize_length = stri__recycling_rule(true, 2, LENGTH(str), LENGTH(pattern));
+    StriContainerUTF16 str_cont(str, vectorize_length);
+    StriContainerUStringSearch pattern_cont(pattern, vectorize_length, collator);  // collator is not owned by pattern_cont
 
-   SEXP ret;
-   STRI__PROTECT(ret = Rf_allocVector(LGLSXP, vectorize_length));
-   int* ret_tab = LOGICAL(ret);
+    SEXP ret;
+    STRI__PROTECT(ret = Rf_allocVector(LGLSXP, vectorize_length));
+    int* ret_tab = LOGICAL(ret);
 
-   for (R_len_t i = pattern_cont.vectorize_init();
-         i != pattern_cont.vectorize_end();
-         i = pattern_cont.vectorize_next(i))
-   {
-      if (max_count_1 == 0) {
-          ret_tab[i] = NA_LOGICAL;
-          continue;
-      }
+    for (R_len_t i = pattern_cont.vectorize_init();
+            i != pattern_cont.vectorize_end();
+            i = pattern_cont.vectorize_next(i))
+    {
+        if (max_count_1 == 0) {
+            ret_tab[i] = NA_LOGICAL;
+            continue;
+        }
 
-      STRI__CONTINUE_ON_EMPTY_OR_NA_STR_PATTERN(str_cont, pattern_cont,
-         ret_tab[i] = NA_LOGICAL,
-         {ret_tab[i] = negate_1;
-          if (max_count_1 > 0 && ret_tab[i]) --max_count_1;})
+        STRI__CONTINUE_ON_EMPTY_OR_NA_STR_PATTERN(str_cont, pattern_cont,
+                ret_tab[i] = NA_LOGICAL,
+        {   ret_tab[i] = negate_1;
+            if (max_count_1 > 0 && ret_tab[i]) --max_count_1;
+        })
 
-      UStringSearch *matcher = pattern_cont.getMatcher(i, str_cont.get(i));
-      usearch_reset(matcher);
-      UErrorCode status = U_ZERO_ERROR;
-      ret_tab[i] = ((int)usearch_first(matcher, &status) != USEARCH_DONE);  // this is F*G slow! :-(
-      if (negate_1) ret_tab[i] = !ret_tab[i];
-      if (max_count_1 > 0 && ret_tab[i]) --max_count_1;
-      STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
-   }
+        UStringSearch *matcher = pattern_cont.getMatcher(i, str_cont.get(i));
+        usearch_reset(matcher);
+        UErrorCode status = U_ZERO_ERROR;
+        ret_tab[i] = ((int)usearch_first(matcher, &status) != USEARCH_DONE);  // this is F*G slow! :-(
+        if (negate_1) ret_tab[i] = !ret_tab[i];
+        if (max_count_1 > 0 && ret_tab[i]) --max_count_1;
+        STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+    }
 
-   if (collator) { ucol_close(collator); collator=NULL; }
-   STRI__UNPROTECT_ALL
-   return ret;
-   STRI__ERROR_HANDLER_END(
-      if (collator) ucol_close(collator);
-   )
-}
+    if (collator) {
+        ucol_close(collator);
+        collator=NULL;
+    }
+    STRI__UNPROTECT_ALL
+    return ret;
+    STRI__ERROR_HANDLER_END(
+        if (collator) ucol_close(collator);
+    )
+    }
