@@ -1,5 +1,5 @@
-/* This file is part of the 'stringi' package for R.
- * Copyright (c) 2013-2019, Marek Gagolewski and other contributors.
+/* This file is part of the 'stringi' project.
+ * Copyright (c) 2013-2020, Marek Gagolewski <https://www.gagolewski.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -52,37 +52,43 @@
  */
 SEXP stri_trans_list()
 {
-   StringEnumeration* trans_enum = NULL;
+    StringEnumeration* trans_enum = NULL;
 
-   STRI__ERROR_HANDLER_BEGIN(0)
+    STRI__ERROR_HANDLER_BEGIN(0)
 
-   UErrorCode status = U_ZERO_ERROR;
-   trans_enum = Transliterator::getAvailableIDs(status); /*The caller should delete this object when done using it. */
-   STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+    UErrorCode status = U_ZERO_ERROR;
+    trans_enum = Transliterator::getAvailableIDs(status); /*The caller should delete this object when done using it. */
+    STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 
-   trans_enum->reset(status);
-   STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+    trans_enum->reset(status);
+    STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 
-   R_len_t n = (R_len_t)trans_enum->count(status);
-   STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+    R_len_t n = (R_len_t)trans_enum->count(status);
+    STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 
-   SEXP ret;
-   STRI__PROTECT(ret = Rf_allocVector(STRSXP, n));
+    SEXP ret;
+    STRI__PROTECT(ret = Rf_allocVector(STRSXP, n));
 
-   // MG: I reckon than IDs are more readable than DisplayNames
-   for (R_len_t i=0; i<n; ++i) {
-      int len;
-      const char* cur = trans_enum->next(&len, status);
-      STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
-      SET_STRING_ELT(ret, i, Rf_mkCharLenCE(cur, len, CE_UTF8));
-   }
+    // MG: I reckon than IDs are more readable than DisplayNames
+    for (R_len_t i=0; i<n; ++i) {
+        int len;
+        const char* cur = trans_enum->next(&len, status);
+        STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+        SET_STRING_ELT(ret, i, Rf_mkCharLenCE(cur, len, CE_UTF8));
+    }
 
-   if (trans_enum) { delete trans_enum; trans_enum = NULL; }
-   STRI__UNPROTECT_ALL
-   return ret;
-   STRI__ERROR_HANDLER_END(
-      if (trans_enum) { delete trans_enum; trans_enum = NULL; }
-   )
+    if (trans_enum) {
+        delete trans_enum;
+        trans_enum = NULL;
+    }
+    STRI__UNPROTECT_ALL
+    return ret;
+    STRI__ERROR_HANDLER_END(
+    if (trans_enum) {
+    delete trans_enum;
+    trans_enum = NULL;
+}
+)
 }
 
 
@@ -96,33 +102,39 @@ SEXP stri_trans_list()
  */
 SEXP stri_trans_general(SEXP str, SEXP id)
 {
-   PROTECT(str = stri_prepare_arg_string(str, "str"));
-   PROTECT(id  = stri_prepare_arg_string_1(id, "id"));
-   R_len_t str_length = LENGTH(str);
+    PROTECT(str = stri_prepare_arg_string(str, "str"));
+    PROTECT(id  = stri_prepare_arg_string_1(id, "id"));
+    R_len_t str_length = LENGTH(str);
 
-   Transliterator* trans = NULL;
-   STRI__ERROR_HANDLER_BEGIN(2)
-   StriContainerUTF16  id_cont(id, 1);
-   if (id_cont.isNA(0)) {
-      STRI__UNPROTECT_ALL
-      return stri__vector_NA_strings(str_length);
-   }
+    Transliterator* trans = NULL;
+    STRI__ERROR_HANDLER_BEGIN(2)
+    StriContainerUTF16  id_cont(id, 1);
+    if (id_cont.isNA(0)) {
+        STRI__UNPROTECT_ALL
+        return stri__vector_NA_strings(str_length);
+    }
 
-   UErrorCode status = U_ZERO_ERROR;
-   trans = Transliterator::createInstance(id_cont.get(0), UTRANS_FORWARD, status);
-   STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+    UErrorCode status = U_ZERO_ERROR;
+    trans = Transliterator::createInstance(id_cont.get(0), UTRANS_FORWARD, status);
+    STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
 
-   StriContainerUTF16 str_cont(str, str_length, false); // writable, no recycle
+    StriContainerUTF16 str_cont(str, str_length, false); // writable, no recycle
 
-   for (R_len_t i=0; i<str_length; ++i) {
-      if (str_cont.isNA(i)) continue;
-      trans->transliterate(str_cont.getWritable(i));
-   }
+    for (R_len_t i=0; i<str_length; ++i) {
+        if (str_cont.isNA(i)) continue;
+        trans->transliterate(str_cont.getWritable(i));
+    }
 
-   if (trans) { delete trans; trans = NULL; }
-   STRI__UNPROTECT_ALL
-   return str_cont.toR();
-   STRI__ERROR_HANDLER_END(
-      if (trans) { delete trans; trans = NULL; }
-   )
+    if (trans) {
+        delete trans;
+        trans = NULL;
+    }
+    STRI__UNPROTECT_ALL
+    return str_cont.toR();
+    STRI__ERROR_HANDLER_END(
+    if (trans) {
+    delete trans;
+    trans = NULL;
+}
+)
 }
